==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/uk/avatars.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>Avatars</name>
    <message>
        <source>Avatar</source>
        <translation>Аватар</translation>
    </message>
    <message>
        <source>Set avatar</source>
        <translation>Встановити аватар</translation>
    </message>
    <message>
        <source>Clear avatar</source>
        <translation>Прибрати аватар</translation>
    </message>
    <message>
        <source>Custom picture</source>
        <translation>Власна картинка</translation>
    </message>
    <message>
        <source>Set custom picture</source>
        <translation>Встановити власну картинку</translation>
    </message>
    <message>
        <source>Clear custom picture</source>
        <translation>Прибрати власну картинку</translation>
    </message>
    <message>
        <source>Select avatar image</source>
        <translation>Обрати аватар</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.gif)</source>
        <translation>Файли зображень</translation>
    </message>
    <message>
        <source>Avatars</source>
        <translation>Аватари</translation>
    </message>
    <message>
        <source>Allows to set and display avatars</source>
        <translation>Дозволяє встановлювати та показувати аватари</translation>
    </message>
    <message>
        <source>Show avatars</source>
        <translation>Показувати аватари</translation>
    </message>
    <message>
        <source>Show empty avatars</source>
        <translation>Показати відсутні аватари</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/uk/avatars.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>Avatars</name>
    <message>
        <source>Avatar</source>
        <translation>Аватар</translation>
    </message>
    <message>
        <source>Set avatar</source>
        <translation>Встановити аватар</translation>
    </message>
    <message>
        <source>Clear avatar</source>
        <translation>Прибрати аватар</translation>
    </message>
    <message>
        <source>Custom picture</source>
        <translation>Власна картинка</translation>
    </message>
    <message>
        <source>Set custom picture</source>
        <translation>Встановити власну картинку</translation>
    </message>
    <message>
        <source>Clear custom picture</source>
        <translation>Прибрати власну картинку</translation>
    </message>
    <message>
        <source>Select avatar image</source>
        <translation>Обрати аватар</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.gif)</source>
        <translation>Файли зображень (*.png *.jpg *.bmp *.gif)</translation>
    </message>
    <message>
        <source>Avatars</source>
        <translation>Аватари</translation>
    </message>
    <message>
        <source>Allows to set and display avatars</source>
        <translation>Дозволяє встановлювати та показувати аватари</translation>
    </message>
    <message>
        <source>Show avatars</source>
        <translation>Показувати аватари</translation>
    </message>
    <message>
        <source>Show empty avatars</source>
        <translation>Показати відсутні аватари</translation>
    </message>
</context>
</TS>
